@@ -1910,10 +1910,10 @@ C     AND IF SO, WRITE OUTPUT.
 	   ALPHA = ALPHA * DG / DG1
 	ELSE
 C	   WRITE(IDEV,50)ITER,IFUN,FMIN,GSQ
- 50	   FORMAT(10H ITERATION,I5,20H      FUNCTION CALLS,I6/5H F = ,
-     1 D15.8,13H G-SQUARED = ,D15.8/)  
+C 50	    FORMAT(10H ITERATION,I5,20H      FUNCTION CALLS,I6/5H F = ,
+C     1 D15.8,13H G-SQUARED = ,D15.8/)  
 C	   WRITE(IDEV,60)(X(I),I=1,N)
- 60	   FORMAT(/8HINTER X./1H ,20D16.8)
+C 60	   FORMAT(/8HINTER X./1H ,20D16.8)
 	END IF
 
 C     IF NMETH=1 OR A RESTART HAS BEEN PERFORMED, SET ALPHA=1.0.
